@@ -1,6 +1,8 @@
 import json
 import os
 
+from RGBMatrixEmulator.adapters import ADAPTER_TYPES
+
 
 class RGBMatrixOptions:
     def __init__(self):
@@ -25,7 +27,15 @@ class RGBMatrixOptions:
             self.pixel_style = emulator_config.pixel_style
         else:
             print('EMULATOR: Warning! "{}" pixel style option not recognized. Valid options are "square", "circle". Defaulting to "square"...'.format(emulator_config.pixel_style))
-            self.pixel_style = 'square'
+            self.pixel_style = emulator_config.default_config().get('pixel_style')
+
+        if emulator_config.display_adapter.lower() in ADAPTER_TYPES:
+            self.display_adapter = ADAPTER_TYPES[emulator_config.display_adapter.lower()]
+        else:
+            adapter_types = ', '.join('"{}"'.format(key) for key in ADAPTER_TYPES.keys())
+            print('EMULATOR: Warning! "{}" display adapter option not recognized. Valid adapters are {}. Defaulting to "pygame"...'.format(emulator_config.display_adapter, adapter_types))
+            self.display_adapter = ADAPTER_TYPES[emulator_config.default_config().get('display_adapter')]
+
 
         self.pixel_size = emulator_config.pixel_size
 
@@ -38,8 +48,9 @@ class RGBMatrixEmulatorConfig:
     def __init__(self):
         self.__config = self.__load_config()
 
-        self.pixel_size = self.__config['pixel_size']
-        self.pixel_style = self.__config['pixel_style']
+        self.pixel_size      = self.__config.get('pixel_size',      16)
+        self.pixel_style     = self.__config.get('pixel_style',     'square')
+        self.display_adapter = self.__config.get('display_adapter', 'pygame')
 
     def __load_config(self):
         if os.path.exists(self.__CONFIG_PATH):
@@ -49,12 +60,13 @@ class RGBMatrixEmulatorConfig:
             return config    
 
         with open(self.__CONFIG_PATH, 'w') as f:
-            json.dump(self.__default_config(), f, indent=4)
+            json.dump(self.default_config(), f, indent=4)
 
-        return self.__default_config()
+        return self.default_config()
 
-    def __default_config(self):
+    def default_config(self):
         return {
             'pixel_size': 16,
-            'pixel_style': 'square'
-        }
\ No newline at end of file
+            'pixel_style': 'square',
+            'display_adapter': 'pygame'
+        }
